Pastebin magic expiry days option
=================================

The Pastebin magic now has ``-e`` option to determine 
the number of days for paste expiration. For example
the paste that created with ``%pastebin -e 20 1`` magic will
be available for next 20 days.
